package record

import (
	"github.com/urfave/cli"
)

// RecordCommand supports managing DNS entries.
var RecordCommand = cli.Command{
	Name:      "record",
	Usage:     "Manage domain name records",
	Aliases:   []string{"rc"},
	ArgsUsage: "<record>",
	Description: `
Manage domain name records via 3rd party providers such as Gandi DNS. It
supports listing, creating and removing all types of records that you might
need for managing Co-op Cloud apps.

The following providers are supported:

    Gandi DNS https://www.gandi.net

You need an account with such a provider already. Typically, you need to
provide an API token on the Abra command-line when using these commands so that
you can authenticate with your provider account.

New providers can be integrated, we welcome change sets. See the underlying DNS
library documentation for more. It supports many existing providers and allows
to implement new provider support easily.

    https://pkg.go.dev/github.com/libdns/libdns
`,
	Subcommands: []cli.Command{
		RecordListCommand,
		RecordNewCommand,
		RecordRemoveCommand,
	},
}
